#
#
#

""" Perform analysis on an intermediate folding pathway """
__author__ = "Magdalena A. Jonikas"
__version__ = "1.0"
__date__ = " 7/23/09 "

import sys
import math

def calcDist(pos1, pos2):
    (x1,y1,z1)=pos1
    (x2,y2,z2)=pos2
    distance = math.sqrt(math.pow((x1-x2),2) + math.pow((y1-y2),2) + math.pow((z1-z2),2))
    return distance

def parseStructure(input):
    pos_D = {} # dictionary to get positions for atoms
    for line in input:
        if line[0:4]=='ATOM':
            resNum = int(line[23:26])
            pos_D[resNum] = (float(line[30:38]),float(line[38:46]), float(line[46:54]))

    return pos_D

def getASAframe(input, R):
    pos_D = parseStructure(input)
    resList = pos_D.keys()
    numRes = len(resList)

    SASA = 0
    A = []
    Rsolv=1.5
    S = 4*math.pi*(R + Rsolv)**2
    p = 1.2
    dCut = 2*R + 2*Rsolv

    for i in range(numRes): # For each residue
        nearList = [] # create list of nearby residues
        for j in range(numRes):
            if i != j: 
                dist = calcDist(pos_D[resList[i]], pos_D[resList[j]])
                if dist < dCut:
                    nearList.append( (j, dist) )
        A.append(S)
        for j, dist in nearList:
            b = math.pi*(R + Rsolv)*(2*R + 2*Rsolv - dist)
            A[i] *= (1-(p*b/S))
    return A

def parseDomains(domainFilename):
    dlines = open(domainFilename).readlines()
    domainIndex=0
    domainList=[]
    domains={}
    for line in dlines:
        if line[0]=='#':
            if len(domainList)>0:
                domains[domainName]=domainList
            cols = line.split()
            domainName=cols[1]
            domainList = []
        else:
            res = int(line)
            domainList.append(res)
    if len(domainList)>0:
        domains[domainName]=domainList
    return domains

def getASA(asalist, reslist):
    valList=[]
    for res in reslist:
        id=res-1
        valList.append(asalist[id])
        if asalist[id]>10.0:
            print res
    valList.sort()
    return valList


if __name__=='__main__':
    name=sys.argv[1]
    inter1=sys.argv[2]
    inter2=sys.argv[3]
    domains=parseDomains('%s-domains.txt' % name)
    resList1 = domains[inter1]
    resList2 = domains[inter2]
    resList=resList1+resList2

    xtalFrame=open('%s-C3.pdb' % name).readlines()
    xtalASA=getASAframe(xtalFrame, 9.0)
    xtalList = getASA(xtalASA, resList)

