#
#
#

""" Find residues within x angstroms of a list of residues """
__author__ = "Magdalena A. Jonikas"
__version__ = "1.0"
__date__ = " 3/5/09 "

import sys
import molClasses
import geom

class Groups:
    def __init__(self, structure,x, p):
        self.groups={}
        self.structure = structure
        self.gID = 0
        self.groupsDef = {}
        self.x = x
        self.p = p

    def newGroupPer(self, resListIn):
        self.groups[self.gID]=[]
        self.groupsDef[self.gID] = []
        for line in resListIn:
            cols = line.split()
            r = int(cols[0])
            p1 = float(cols[1])
            p2 = float(cols[2])
            if p1 > self.p and p2 > self.p: self.groupsDef[self.gID].append(r)
        for resi in self.structure.res2index.keys():
            coordsi = self.structure.getResCoords(resi)
            for resj in self.groupsDef[self.gID]:
                coordsj = self.structure.getResCoords(resj)
                dist = geom.calcDist(coordsi, coordsj)
                if dist < self.x:
                    self.addResToGroup(self.gID, resi)
                    break
        self.gID+=1

    def newGroup(self, resListIn):
        self.groups[self.gID]=[]
        self.groupsDef[self.gID] = []
        for line in resListIn:
            cols = line.split()
            r = int(cols[0])
            v1 = float(cols[1])
            if v1 < self.p : self.groupsDef[self.gID].append(r)
            #if c2 > self.p or c3 > self.p: self.groupsDef[self.gID].append(r)
        for resi in self.structure.res2index.keys():
            coordsi = self.structure.getResCoords(resi)
            for resj in self.groupsDef[self.gID]:
                coordsj = self.structure.getResCoords(resj)
                dist = geom.calcDist(coordsi, coordsj)
                if dist < self.x:
                    self.addResToGroup(self.gID, resi)
                    break

    def printResList(self):
        lines = ''
        for gID in self.groupsDef.keys():
            for res in self.groupsDef[gID]:
                lines+='%i\n' % res
        return lines

    def addResToGroup(self, gID, res):
        self.groups[gID].append(res)

    def makePT(self):
        lines = ''
        for g in self.groups.keys():
            list = self.groups[g]
            for i in range(len(list)):
                resi = list[i]
                posi = self.structure.getResCoords(resi)
                for j in range(i+1,len(list)):
                    resj = list[j]
                    posj = self.structure.getResCoords(resj)
                    dist = geom.calcDist(posi, posj)
                    if dist<30.0: lines += '%i %i %.2f %.2f\n' % (resi, resj, dist, 10.0)
        return lines
                    

    def printGroups(self):
        index = 0
        for g in self.groups.keys():
            list = self.groups[g]
            list.sort()
            lastRes = -1
            line = 'Group %i (%i)\n' % (index, len(list))
            line+='resid '
            first = 1
            for res in list:
                if res != (lastRes+1): 
                    start = res
                    if first: 
                        line+='%i to ' % start
                        first = 0
                    else: line+='%i or resid %i to ' % (lastRes, start)
                lastRes = res
            line+='%i\n' % lastRes
            print line
            index+=1
                
if __name__=='__main__':
    frame = open(sys.argv[1])
    resListIn = open(sys.argv[2]).readlines()
    x = float(sys.argv[3])
    p = float(sys.argv[4])
    dataOut = open('%s-%.2f-%.2f-PT.txt' % (sys.argv[2][:-4], x, p), 'w')
    resListOut = open('%s-%.2f-%.2f-resList.txt' % (sys.argv[2][:-4], x, p), 'w')

    domainListNR = []
    domainListAll = []

    structure = molClasses.Coarse(frame)
    g = Groups(structure, x, p)

    g.newGroup(resListIn)

    g.printGroups()
    lines = g.makePT()
    dataOut.write(lines)
    dataOut.close()

    lines = g.printResList()
    resListOut.write(lines)
    resListOut.close()
