
__author__ = "Magdalena Jonikas"
__version__ = "1.0"
__doc__ = """Fold through the intermediate"""
__dat__ = "7/21/09"

import time
import sys
import simtk.nast.molecule as molecule

t0=time.time()
moleculeName = sys.argv[1]
intermediateName = sys.argv[2]
moleculeIndex = int(sys.argv[3]) # index of starting structure
printTrace = True

helixFilename		= "%s-helix.txt" % moleculeName
pdbInFilename		= '%s-%i.pdb' % (moleculeName, moleculeIndex)
traceIFilename = '%s-%i-%s-Itrace.pdb' % (moleculeName, moleculeIndex, intermediateName)
traceFFilename = '%s-%i-%s-Ftrace.pdb' % (moleculeName, moleculeIndex, intermediateName)
intermediateFilename = '%s-%i-%s-I.pdb' % (moleculeName, moleculeIndex, intermediateName)
foldedFilename = '%s-%i-%s-F.pdb' % (moleculeName, moleculeIndex, intermediateName)

contactsFilename	= ""
numSteps		= 10000
stepsPerReport		= 100
defaultTemperature	= 300.0
randomSeed		= None
tryUsingGpu			= False
verbose			= False

# Fold from unfolded to intermediate
startName=pdbInFilename
for state, stateName in [('I',intermediateName), ('F', 'F')]:
    pdbOutFilename='%s-%i-%s-%s.pdb' % (moleculeName, moleculeIndex, intermediateName, state)
    for strength in ['W','S']:
        #print "Running", startName, state, stateName, strength
        traceFilename='%s-%i-%s-%s%strace.pdb' % (moleculeName, moleculeIndex, intermediateName, state, strength)
        contactsFilename='%s-%s-PT-%s.txt' % (moleculeName, stateName, strength)
        m=molecule.Molecule(pdbFilename=startName,
                    helixFilename=helixFilename,
                    contactsFilename=contactsFilename,
                    defaultTemperature=defaultTemperature,
                    randomSeed=randomSeed,
                    tryUsingGpu=tryUsingGpu)
        fEnergyOut=None
        m.doSimulation(numSteps=numSteps,
                        pdbOutFilename=traceFilename,
                        stepsPerReport=stepsPerReport,
                        fEnergyOut=fEnergyOut)

        (t, eK, eP, p, v, f) =  m.context.getState(getPositions=True,
                                                  getVelocities=False,
                                                  getForces=False)
        s='REMARK  ENERGIES: EK = %0.1f EP = %0.1f\n' % (eK, eP)
        s+='REMARK  TIME (sec): %.2f\n' % (time.time()-t0)
        s+=m.pdb.getPdb(positions=p, useOriginalPdb=False)
        s+='END\n'
        fPdbOut = open(pdbOutFilename, 'w')
        fPdbOut.writelines(s)
        fPdbOut.close()
        startName=pdbOutFilename


