
__author__ = "Magdalena Jonikas"
__version__ = "1.0"
__doc__ = """Script to ~minimize~ unfolded strcutures with 100 steps of simulation"""

import unfoldingTools as u
import time
import sys
import simtk.nast.molecule as molecule

t0=time.time()
pdbInFilename		= '%s.pdb' % sys.argv[1]
pdbOutFilename		= "%s-last.pdb" % sys.argv[1]
helixFilename		= "%s-helix.txt" % sys.argv[2]
contactsFilename	= ""
numSteps		= 10000
stepsPerReport		= 1000
defaultTemperature	= 300.0
randomSeed		= 1
tryUsingGpu			= False
verbose			= True

m=molecule.Molecule(pdbFilename=pdbInFilename,
                    helixFilename=helixFilename,
                    defaultTemperature=defaultTemperature,
                    randomSeed=randomSeed,
                    tryUsingGpu=tryUsingGpu)
fEnergyOut=None
m.doSimulation(numSteps=numSteps,
            stepsPerReport=stepsPerReport,
            fEnergyOut=fEnergyOut)

(t, eK, eP, p, v, f) =  m.context.getState(getPositions=True,
                                                  getVelocities=False,
                                                  getForces=False)
s='REMARK  ENERGIES: EK = %0.1f EP = %0.1f\n' % (eK, eP)
s+='REMARK  TIME (sec): %.2f\n' % (time.time()-t0)
s+=m.pdb.getPdb(positions=p, useOriginalPdb=False)
s+='END\n'
fPdbOut = open(pdbOutFilename, 'w')
fPdbOut.writelines(s)
fPdbOut.close()


